/*                                                              */
/*                                                              */
/*  This Program is free software, distributed under the terms  */
/*  of the GNU General Public License. See the file COPYING or  */
/*  http://www.fsf.org for more information.                    */
/*                                                              */
/*  fusor.c         (c) Diane Neisius   (diane_va@yahoo.com)    */
/*                                                              */
/*                                                              */
/*--------------------------------------------------------------*/
/*                                                              */
/*                         Fusor  Program                       */
/*                                                              */
/*                              for                             */
/*                                                              */
/*                                                              */
/*    Calculation of Helium Reaction Rates in a fusor focus     */
/*                                                              */
/*              by Diane Neisius,  August 22, 2006              */
/*                                                              */
/*                                                              */
/*                                                              */
/*                                                              */
/* Ref1: Nomoto, K., Thielemann, F.-K., Miyaji, S.:             */
/*       The triple alpha reaction in accreting white dwarfs    */
/*       and neutron stars,                                     */
/*       Astron. Astrophys. 149(1985) p.239                     */
/*                                                              */
/* Ref2: Adelberger, E. G. et al:                               */
/*       Solar fusion cross sections                            */
/*       Rev. Mod. Phys. 70(1998) p.1265                        */
/*                                                              */


# include <stdio.h> 
# include <math.h>

/* Global Constants */

const double pi            = M_PI;        /*        3.1415...          */
const double joule_fac     = 1.602e-19;   /* J / eV                    */
const double na            = 6.022e+23;   /* 1/mol  , Avogadro's Num.  */
const double ec            = 1.602e-19;   /* C      , electron charge  */
const double m_alpha       = 6.640e-27;   /* kg     , alpha particle   */
const double cone          = 0.879645943; /* solid angle of 60 deg, -  */
                                          /* ( for:  cos 30 deg = .86  */


double sigma( double e )                        /* e input in eV, sigma return in barn */
   {
      const double joule_fac     = 1.602e-19;   /* J / eV                    */
      const double m_u           = 1.660e-27;   /* kg     , nuc. mass unit   */
      const double ec            = 1.602e-19;   /* C      , electron charge  */
      const double h             = 6.626e-34;   /* Js     , Planck const.    */
      const double eps           = 8.854e-12;   /* As/Vm  , elec. field const*/
      
      double e3, v, sigma1;
      double a, a1, a2, z1, z2, eta, mu;
      double p, gamma1, gamma2; 
      double er, pr, vr, etar;      /* at resonance energy er */
      double gamma_a, gamma_g;
   
      a1 =  4.0;
      z1 =  2.0;     /*  4He */
      
      a2 =  4.0;
      z2 =  2.0;     /*  4He */
      
      a  = a1 * a2 / ( a1 + a2 );
      mu = m_u * a; 
      
      er   = 9.178e+4;                         /* a + a resonance energy in eV */
      vr   = sqrt( 2.0 * er * joule_fac / mu ); 
      etar = z1 * z2 * ec * ec / ( 2 * eps * h * vr );
      pr   = sqrt( er ) * exp( -2 * pi * etar );
      gamma_a = 6.8;                          /* width of a + a resonance in eV */
      
      e3  = e / 1e+3;                         /* keV  */ 
      v   = sqrt( 2.0 * e * joule_fac / mu ); /* m/s  */
	   
      eta = z1 * z2 * ec * ec / ( 2 * eps * h * v ); 
	   
      p = sqrt( e ) * exp( -2 * pi * eta );       /* tunneling probability factor */
	   
      gamma1 = gamma_a * p / pr;
      gamma2 = gamma_a;                            /* according to Nomoto paper */
	   
      sigma1 = 0.6566 / ( a * e/1e+6 ) * gamma1 * gamma2 / ( pow( (e - er), 2.0) + gamma_a  * gamma_a / 4 );
	                        /* S(E) of the Nomoto paper was in MeV barn */
      return sigma1;	   
   }



/* main procedure */

int main( void )
   {
     /* Global Variables */

      double u, i, d, p, delta;         /* input values */
      double v;
      double n_beam, n_beam_dens, n_target, n_transient, vol, sur, d0;
      double n, nn, sum, sum_head, headon;

      printf(" \n FUSOR -- (c) Diane Neisius (diane_va@yahoo.com)\n\n");
   
      printf(" This program is free software, distributed under the terms\n");
      printf(" of the GNU General Public License. See the file COPYING or\n");
      printf(" http://www.fsf.org for more information.\n\n");
      
      
      printf(" *** Fusor Parameter Input ***\n");
      printf("\n Grid Voltage (kV)         : ");
      scanf ("%lf", &u );
      printf("\n Discharge current (mA)    : ");
      scanf ("%lf", &i );
      printf("\n Helium Pressure (Torr)    : ");
      scanf ("%lf", &p );
      printf("\n Focus Precision (mm)      : ");
      scanf ("%lf", &delta );
      printf("\n\n *** MONOENERGETIC Rates in Focus Shells ***\n\n");
      
      /* focus diameter loop 
         note that all the stuff done here is valid only if the fusor
	 is very precise focused (means error in grid sphere center 
	 alignment is smaller than 0.05 mm (!!) */
      
      sum = 0.0;
      sum_head = 0.0;
      d0  = 25.0;
      
      n_beam = i / 1e+3 / ( 2*ec );                /* a has TWO charges */
      u      = u * 1e+3 *   2;                     /* a has TWO charges */
                                                   /* 2u in V = e in eV */ 
      v   = sqrt( 2.0 * u * joule_fac / m_alpha ) * 100;/* cm/s  */
      
      headon = cone /( 4 * pi );                   /* solid angle part of +/- 30 deg 
                                                      versus full sphere              */
      
      for ( d=d0-1.0; d>=delta; d-= (1.0 * (d>1.0)) + (0.1 * (d<=1.0) ) )
        {
          vol = (  4.0/3.0 * pi * pow( d0/2, 3 ) 
	         - 4.0/3.0 * pi * pow( d/2, 3 )
	        )  
		      / 1e+3;                        /* shell vol in cm^3 */
		
          sur = 4.0 *pi * d*d/4 /100.0;              /* srf in cm^2   */
          n_target = p/760.0 * vol/22400.0 * na;     /* 22400 is mol vol in cm^3 */
      
          /* now goto particle beam DENSITY... */
          n_beam_dens = n_beam / sur;                /* particles per cm^2 and sec */
	  
	  n_transient = n_beam * (d0-d)/10 / v;      /* d in mm,  v in cm/s  */
	  
	  n  = n_beam_dens * ( n_target + (1-headon) * n_transient ) * sigma(   u ) * 1e-24;
	  nn = n_beam_dens                 * headon  * n_transient   * sigma( 2*u ) * 1e-24; 
	      /* head-on collisions have double relative speed thus MUCH better sigma */
	       
	  sum      += n;
	  sum_head += nn;
	  
	  printf(" d=%4.1lf mm  head-on r(aa) = %8.3le 1/s   all other r(aa) = %8.3le 1/s \n", d, nn, n );
	  
	  d0 = d;
        }
	
	/* once again for center sphere */
	
	vol = (  4.0/3.0 * pi * pow( d0/2, 3 ) )
	      / 1e+3;                                /* shell vol in cm^3 */
		
        sur = 4.0 *pi * d0*d0/4 /100.0;              /* srf in cm^2   */
        n_target = p/760.0 * vol/22400.0 * na;       /* 22400 is mol vol in cm^3 */
      
        /* now goto particle beam DENSITY... */
        n_beam_dens = n_beam / sur;                  /* particles per cm^2 and sec */
	  
        n_transient = n_beam * (d0/10) / v;          /* d in mm,  v in cm/s  */
	  
        n  = n_beam_dens * ( n_target + (1-headon) * n_transient ) * sigma(   u ) * 1e-24;
	nn = n_beam_dens                 * headon  * n_transient   * sigma( 2*u ) * 1e-24; 
	  /* head-on collisions have double relative speed thus MUCH better sigma */
	       
        sum      += n;
	sum_head += nn;
	  
        printf(" center     head-on r(aa) = %8.3le 1/s   all other r(aa) = %8.3le 1/s \n", nn, n );
	                     
	/* end center sphere */
	
	printf("\n Sum:  head-on %8.3le per second,         plain %8.3le per second", sum_head, sum );
	printf("\n       sigma( %3.1lf keV ) =  %8.3le barn,  sigma( %3.1lf keV ) = %8.3le barn\n", 
	                 2*u/1e+3, sigma(2*u), u/1e+3, sigma(u) );
	printf("\n Total:        %8.3le per second\n             ( 1 reaction every %8.3le seconds )\n\n",
	                 sum + sum_head, 1/(sum + sum_head) );
      
      
      return 0;
   }     
