/*                                                              */
/*                                                              */
/*  This Program is free software, distributed under the terms  */
/*  of the GNU General Public License. See the file COPYING or  */
/*  http://www.fsf.org for more information.                    */
/*                                                              */
/*  sigma_a+Be.c    (c) Diane Neisius   (diane_va@yahoo.com)    */
/*                                                              */
/*                                                              */
/*--------------------------------------------------------------*/
/*                                                              */
/*             SIGMA A+BE (alpha-Beryllium) Program             */
/*                                                              */
/*                              for                             */
/*                                                              */
/*                Calculation of the sigma values               */
/*                       of parts of the                        */
/*                  4He + 4He nuclear reaction                  */
/*                                                              */
/*              by Diane Neisius, August 22, 2006               */
/*                                                              */
/*                                                              */
/* Ref1: Nomoto, K., Thielemann, F.-K., Miyaji, S.:             */
/*       The triple alpha reaction in accreting white dwarfs    */
/*       and neutron stars,                                     */
/*       Astron. Astrophys. 149(1985) p.239                     */
/*                                                              */
/* Ref2: Adelberger, E. G. et al:                               */
/*       Solar fusion cross sections                            */
/*       Rev. Mod. Phys. 70(1998) p.1265                        */
/*                                                              */

# include <stdio.h> 
# include <math.h>

/* Global Constants */

const double pi            = M_PI;        /*        3.1415...          */
const double t7fac         = 1e+7;
const double t9fac         = 1e+9;
const double temp          = 11605.0;     /* K / eV                    */
const double joule_fac     = 1.602e-19;   /* J / eV                    */
const double k             = 1.380e-23;   /* J / K  , Boltzman const.  */
const double m_alpha       = 6.640e-27;   /* kg     , alpha particle   */
const double u             = 1.660e-27;   /* kg     , nuc. mass unit   */
const double barn          = 1e-24;       /* 1/cm^2 , 1 barn           */
const double c             = 3e+8;        /* m/s    , light speed      */
const double ec            = 1.602e-19;   /* C      , electron charge  */
const double h             = 6.626e-34;   /* Js     , Planck const.    */
const double eps           = 8.854e-12;   /* As/Vm  , elec. field const*/
   
/* Global Variables */

double t6, t7;
double e, e2, e3, v, sigma1, sigma2, sigma_v;      /* actual values */
double a, a1, a2, z1, z2, eta, mu;
double s;
double p, gamma1, gamma2; 
double er, pr, vr, etar;      /* at resonance energy er */
double gamma_a, gamma_g;


/* main procedure */

int main( void )
   {

      printf(" \n SIGMA A+BE -- (c) Diane Neisius (diane_va@yahoo.com)\n\n");
   
      printf(" This program is free software, distributed under the terms\n");
      printf(" of the GNU General Public License. See the file COPYING or\n");
      printf(" http://www.fsf.org for more information.\n");
   
      printf("\n  MONOENERGETIC  sigma:          alpha + 8Be  ->  12C " );
      printf("\n\n");
      printf("  E-kin (keV)   T (10^6 K)  v (cm/s)       S(E) (keV barn)    sigma(barn)\n");
      printf(" ------------------------------------------------------------------------\n");
      
      /*                         */
      /* MAIN CALCULATION LOOP 1 */
      /*                         */
      
      a1 =  8.0;
      z1 =  4.0;     /*  8Be */
      
      a2 =  4.0;
      z2 =  2.0;     /*  4He */
      
      a  = a1 * a2 / ( a1 + a2 );
      mu = u * a; 
      
      er   = 2.877e+5;                        /* a + Be resonance energy in eV */
      vr   = sqrt( 2.0 * er * joule_fac / mu ); 
      etar = z1 * z2 * ec * ec / ( 2 * eps * h * vr );
      pr   = sqrt( er ) * exp( -2 * pi * etar );
      gamma_a = 8.5;                          /* width of a + Be resonance in eV */
      gamma_g = 3.7e-3;                       /* width of 12C (O+) -> 12C (2+) decay in eV */
      
      for ( t7=1.0; t7<=110.0; t7+=2.0 )
        {  
	   e   = k * t7 * t7fac;                         /*  J   */
	   e2  = t7 * t7fac / temp;                      /*  eV  */
	   e3  = e2 / 1e+3;                              /* keV  */ 
	   t6 = 10.0 * t7;                            
	   v   = sqrt( 2.0 * e / mu );                   /* m/s  */
	   
	   eta = z1 * z2 * ec * ec / ( 2 * eps * h * v ); 
	   
	   p = sqrt( e2 ) * exp( -2 * pi * eta );        /* tunneling probability factor */
	   
	   gamma1 = gamma_a * p / pr;
	   gamma2 = gamma_g * pow( (2.928 + e2/1e+6) / 3.2157, 5 );/* according to Nomoto paper, e in MeV*/
	   
	   sigma1 = 0.6566 / ( a * e2/1e+6 ) * gamma1 * gamma2 / ( pow( (e2 - er), 2.0) + gamma_a  * gamma_a / 4 );
	                        /* S(E) of the Nomoto paper was in MeV barn */
	   
	   s      = sigma1 * e3 * exp( 2 * pi * eta );   /* e3 is in keV */
	   
	   
      /* output loop */
      printf("  %6.3lf        %3.0lf         %8.3le      %8.3le          %8.3le\n", e3, t7*10, v*100, s, sigma1 );
	 };

      printf("\n");	
      return 0;
   }     
